<?php
/**
 * Admin settings page for the plugin.
 *
 * @package    Genesis Prose Extras
 * @subpackage Admin Settings
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright (c) 2013, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL-2.0+
 * @link       http://genesisthemes.de/en/wp-plugins/genesis-prose-extras/
 * @link       http://deckerweb.de/twitter
 *
 * @since      1.0.0
 */

/**
 * Prevent direct access to this file.
 *
 * @since 1.0.0
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Sorry, you are not allowed to access this file directly.' );
}


/**
 * Registers a new admin page, providing content and corresponding menu item
 * for the plugin's admin settings page.
 *
 * @since 1.0.0
 */
class DDW_GPEX_Plugin_Settings extends Genesis_Admin_Boxes {

	/**
	 * Create an admin menu item and settings page.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		/** Set a unique settings page ID */
		$page_id = 'gpex-prose-extras';

		/** Set it as a submenu to 'genesis', and define the menu and page titles */
		$menu_ops = array(
			'submenu' => array(
				'parent_slug' => ( defined( 'PROSE_DOMAIN' ) ) ? 'genesis' : '',
				'page_title'  => _x( 'Genesis Prose Extras', 'Translators: Genesis settings page title', 'genesis-prose-extras' ),
				'menu_title'  => _x( 'Prose Extras', 'Translators: Genesis menu title', 'genesis-prose-extras' ),
				'capability'  => 'edit_theme_options',
			)
		);

		/** Set up page options */
		$page_ops = array(
			'screen_icon'       => 'themes',
			'save_button_text'  => __( 'Save Settings', 'genesis-prose-extras' ),
			'reset_button_text' => __( 'Reset Settings', 'genesis-prose-extras' ),
			'save_notice_text'  => __( 'Genesis Prose Extras settings saved.', 'genesis-prose-extras' ),
			'reset_notice_text' => __( 'Genesis Prose Extras settings were reset to their default values.', 'genesis-prose-extras' ),
		);		

		/** Unique settings field */
		$settings_field = 'gpex-settings';

		/** Set the default values */
		$default_settings = array(
			'home_top_widget_area'   => 1,
			'home_left_widget_area'  => 1,
			'home_right_widget_area' => 1,
			'home_extra_sidebar'     => 0,
			'home_no_footer_widgets' => 0,
			'home_layout'            => '',
			'menu_positions'         => 'default',
			'menu_descriptions'      => 0,
			'layout_sbc'             => 1,
			'layout_c_salt'          => 1,
			'layout_salt_c'          => 1,
			'after_post_widget_area' => 1,
			'after_page_widget_area' => 1,
			'formal_translations'    => 1,
			'multisite_files'        => 0,
			'multisite_hook'         => 'after_setup_theme',
			'multisite_priority'     => 10,
		);

		/** Create the Admin Page */
		$this->create( $page_id, $menu_ops, $page_ops, $settings_field, $default_settings );

		/** Initialize the Sanitization Filter */
		add_action( 'genesis_settings_sanitizer_init', array( $this, 'sanitization_filters' ) );

	}  // end of method __construct


	/** 
	 * Set up Sanitization Filters.
	 *
	 * @since 1.0.0
	 *
	 * @uses  genesis_add_option_filter()
	 */	
	function sanitization_filters() {

		genesis_add_option_filter(
			'one_zero',
			$this->settings_field,
			array( 
				'home_top_widget_area',
				'home_left_widget_area',
				'home_right_widget_area',
				'home_extra_sidebar',
				'home_no_footer_widgets',
				'menu_descriptions',
				'layout_sbc',
				'layout_c_salt',
				'layout_salt_c',
				'after_post_widget_area',
				'after_page_widget_area',
				'formal_translations',
				'multisite_files',
			)
		);

		genesis_add_option_filter(
			'no_html',
			$this->settings_field,
			array(
				'home_layout',
				'menu_positions',
				'multisite_hook',
				'multisite_priority',
			)
		);

	}  // end of method sanitization_filters


	/**
	 * Register metaboxes on the plugin's settings page.
	 *
	 * @since 1.0.0
	 *
	 * @uses  add_meta_box()
	 * @uses  is_multisite()
	 * @uses  is_super_admin()
	 * @uses  current_user_can()
	 */
	function metaboxes() {

		/** Plugin Information Meta Box */
		add_meta_box(
			'gpex-plugin-information',
			__( 'Information', 'genesis-prose-extras' ),
			array( $this, 'gpex_plugin_information' ),
			$this->pagehook,
			'main',
			'high'
		);

		/** Home Template Meta Box */
		add_meta_box(
			'gpex-home-template-metabox',
			__( 'Home Template', 'genesis-prose-extras' ),
			array( $this, 'gpex_home_template_metabox' ),
			$this->pagehook,
			'main',
			'high'
		);

		/** Navigation Menus Meta Box */
		add_meta_box(
			'gpex-navigation-menus-metabox',
			_x( 'Navigation Menus', 'Translators: meta box title', 'genesis-prose-extras' ),
			array( $this, 'gpex_navigation_menus_metabox' ),
			$this->pagehook,
			'main',
			'high'
		);

		/** Layouts Meta Box */
		add_meta_box(
			'gpex-layouts-metabox',
			_x( 'Layouts', 'Translators: meta box title', 'genesis-prose-extras' ),
			array( $this, 'gpex_layouts_metabox' ),
			$this->pagehook,
			'main',
			'high'
		);

		/** Main Content Area Meta Box */
		add_meta_box(
			'gpex-main-content-area-metabox',
			_x( 'Main Content Area', 'Translators: meta box title', 'genesis-prose-extras' ),
			array( $this, 'gpex_main_content_area_metabox' ),
			$this->pagehook,
			'main',
			'high'
		);

		/** Prose Translations Meta Box */
		if ( function_exists( 'ddw_gpex_load_prose_translations' ) ) {

			add_meta_box(
				'gpex-prose-translations',
				__( 'Prose Translations', 'genesis-prose-extras' ),
				array( $this, 'gpex_prose_translations_metabox' ),
				$this->pagehook,
				'main',
				'high'
			);

		}  // end-if translations loader check

		/** Multisite Site Functions Meta Box */
		if ( is_multisite() && is_super_admin() && function_exists( 'prose_get_stylesheet_location' ) ) {

			add_meta_box(
				'gpex-multisite-files',
				__( 'Multisite Site Functions', 'genesis-prose-extras' ),
				array( $this, 'gpex_multisite_files_metabox' ),
				$this->pagehook,
				'main',
				'high'
			);

		}  // end-if is_multisite() & Prose check

		/** Settings Export/ Import Meta Box - only display for Administrators! */
		if ( current_user_can( 'administrator' ) && ! GPEX_NO_EXPORT_IMPORT_INFO ) {

			add_meta_box(
				'gpex-export-import',
				__( 'Export/ Import Info', 'genesis-prose-extras' ),
				array( $this, 'gpex_export_import_metabox' ),
				$this->pagehook,
				'main',
				'high'
			);

		}  // end-if cap check

		/** Action hook 'gpex_settings_metaboxes' */
		do_action( 'gpex_settings_metaboxes', $this->pagehook );

	}  // end of method metaboxes


	/**
	 * Plugin Information Metabox.
	 *
	 * @since 1.0.0
	 */
	function gpex_plugin_information() {

		/** Begin form code unix: strtotime( '1358488800' ) */
		?>

		<p>
			<strong><?php _e( 'Genesis Prose Extras', 'genesis-prose-extras' ); ?></strong> <?php _e( 'by', 'genesis-prose-extras' ); ?> <a href="<?php echo esc_url( GPEX_URL_PLUGIN ); ?>" target="_new" title="David Decker - DECKERWEB &amp; wpAUTOBAHN.com">David Decker - DECKERWEB &amp; wpAUTOBAHN.com</a>
		</p>

		<p>
			<strong><?php _e( 'Version:', 'genesis-prose-extras' ); ?></strong> <?php echo esc_attr( ddw_gpex_plugin_get_data( 'Version' ) ); ?> <?php echo '&middot;'; ?> <strong><?php _e( 'Released:', 'genesis-prose-extras' ); ?></strong> <?php echo date_i18n( __( 'F j, Y', 'genesis-prose-extras' ), '1374105600' ); ?>
		</p>

		<p>
			<span class="description"><?php echo sprintf( __( 'Support for this plugin is provided via %sour support forum%s.', 'genesis-prose-extras' ), '<a href="' . esc_url( GPEX_URL_SUPPORT ) . '">', '</a>' ); echo ' &mdash; '; ?><a href="<?php echo esc_url( GPEX_URL_TRANSLATE ); ?>" target="_new" title="<?php _e( 'Free Translations Platform', 'genesis-prose-extras' ); ?>"><?php _e( 'Free Translations Platform', 'genesis-prose-extras' ); ?></a>
			<br /><br /><?php echo sprintf( __( 'General support for the Genesis Framework and the Prose Child Theme you can get at %s.', 'genesis-prose-extras' ), '<a href="http://deckerweb.de/go/studiopress-support/">My.StudioPress.com</a>' ); ?></span>
		</p>

		<?php
		/** ^End form code */

	}  // end of method gpex_plugin_information


	/**
	 * Home Template Metabox.
	 *
	 * @since 1.0.0
	 *
	 * @uses  ddw_gpex_styles_layout_dropdown()
	 */
	function gpex_home_template_metabox() {

		$gpex_content_tag = ( function_exists( 'genesis_html5' ) && genesis_html5() ) ? 'main.content' : '#content';

		/** Begin form code */
		?>

		<h4><?php echo sprintf( __( '%s for Homepage template.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'widgets.php' ) . '" title="' . __( 'Go to the Widgets settings page', 'genesis-prose-extras' ) . '">' . __( 'Widget areas', 'genesis-prose-extras' ) . '</a>' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'home_top_widget_area' ); ?>" id="<?php echo $this->get_field_id( 'home_top_widget_area' ); ?>" value="1"<?php checked( $this->get_field_value( 'home_top_widget_area' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'home_top_widget_area' ); ?>">
					<?php echo sprintf( __( 'Enable %s widget area for Homepage?', 'genesis-prose-extras' ), '<em>' . __( 'Home Top', 'genesis-prose-extras' ) . '</em>' ); ?>
					<br /> &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?> &nbsp;/&nbsp; <?php echo sprintf( __(' Width: %s', 'genesis-prose-extras' ), '<code>' . $gpex_content_tag . '</code> ' . __( 'default', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'home_left_widget_area' ); ?>" id="<?php echo $this->get_field_id( 'home_left_widget_area' ); ?>" value="1"<?php checked( $this->get_field_value( 'home_left_widget_area' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'home_left_widget_area' ); ?>">
					<?php echo sprintf( __( 'Enable %s widget area for Homepage?', 'genesis-prose-extras' ), '<em>' . __( 'Home Left', 'genesis-prose-extras' ) . '</em>' ); ?>
					<br /> &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?> &nbsp;/&nbsp; <?php echo sprintf( __(' Width: %s', 'genesis-prose-extras' ), '<code>' . $gpex_content_tag . '</code> ' . __( '50% column', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'home_right_widget_area' ); ?>" id="<?php echo $this->get_field_id( 'home_right_widget_area' ); ?>" value="1"<?php checked( $this->get_field_value( 'home_right_widget_area' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'home_right_widget_area' ); ?>">
					<?php echo sprintf( __( 'Enable %s widget area for Homepage?', 'genesis-prose-extras' ), '<em>' . __( 'Home Right', 'genesis-prose-extras' ) . '</em>' ); ?>
					<br /> &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?> &nbsp;/&nbsp; <?php echo sprintf( __(' Width: %s', 'genesis-prose-extras' ), '<code>' . $gpex_content_tag . '</code> ' . __( '50% column', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

		<hr class="div" />

		<h4><?php echo sprintf( __( 'Extra Sidebar for Homepage template.', 'genesis-prose-extras' ), '' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'home_extra_sidebar' ); ?>" id="<?php echo $this->get_field_id( 'home_extra_sidebar' ); ?>" value="1"<?php checked( $this->get_field_value( 'home_extra_sidebar' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'home_extra_sidebar' ); ?>">
					<?php echo sprintf( __( 'Enable %s for Homepage?', 'genesis-prose-extras' ), '<em>' . __( 'Extra Sidebar', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'disabled', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

			<p>
				<span class="description"><?php echo sprintf( __( 'Note: This will replace the default %s.', 'genesis-prose-extras' ), '<em>&raquo;' . __( 'Primary Sidebar', 'genesis-prose-extras' ) . '&laquo;</em>' ); ?></span>
			</p>

		<hr class="div" />

		<h4><?php echo sprintf( __( '%s on home page/ static front page.', 'genesis-prose-extras' ), '<em>' . __( 'Footer Widgets', 'genesis-prose-extras' ) . '</em>' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'home_no_footer_widgets' ); ?>" id="<?php echo $this->get_field_id( 'home_no_footer_widgets' ); ?>" value="1"<?php checked( $this->get_field_value( 'home_no_footer_widgets' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'home_no_footer_widgets' ); ?>">
					<?php echo sprintf( __( 'Remove the %s on home page/ static front page?', 'genesis-prose-extras' ), '<em>' . __( 'Footer Widgets', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'disabled', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

		<hr class="div" />

		<h4><?php echo sprintf( __( 'Layout for Homepage template.', 'genesis-prose-extras' ), '' ); ?></h4>

		<?php
			/** Check if "Genesis Layout Extras" plugin is active */
			if ( ! defined( 'GLE_PLUGIN_BASEDIR' ) ) {
		?>

			<p>
				<label for="<?php echo $this->get_field_id( 'home_layout' ); ?>"><?php _e( 'Choose layout option:', 'genesis-prose-extras' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'home_layout' ); ?>" id="<?php echo $this->get_field_id( 'home_layout' ); ?>">

					<option <?php ddw_gpex_styles_layout_dropdown( '#fff' ); ?> value=""<?php selected( $this->get_field_value( 'home_layout' ), '' ); ?>><?php _e( 'Genesis Default', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#eee' ); ?> value="content-sidebar"<?php selected( $this->get_field_value( 'home_layout' ), 'content-sidebar' ); ?>><?php _e( 'Content-Sidebar', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#eee' ); ?> value="sidebar-content"<?php selected( $this->get_field_value( 'home_layout' ), 'sidebar-content' ); ?>><?php _e( 'Sidebar-Content', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#fafafa' ); ?> value="content-sidebar-sidebar"<?php selected( $this->get_field_value( 'home_layout' ), 'content-sidebar-sidebar' ); ?>><?php _e( 'Content-Sidebar-Sidebar', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#fafafa' ); ?> value="sidebar-sidebar-content"<?php selected( $this->get_field_value( 'home_layout' ), 'sidebar-sidebar-content' ); ?>><?php _e( 'Sidebar-Sidebar-Content', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#fafafa' ); ?> value="sidebar-content-sidebar"<?php selected( $this->get_field_value( 'home_layout' ), 'sidebar-content-sidebar' ); ?>><?php _e( 'Sidebar-Content-Sidebar', 'genesis-prose-extras' ); ?></option>

					<option <?php ddw_gpex_styles_layout_dropdown( '#ddd' ); ?> value="full-width-content"<?php selected( $this->get_field_value( 'home_layout' ), 'full-width-content' ); ?>><?php _e( 'Full-Width-Content', 'genesis-prose-extras' ); ?></option>

					<?php if ( genesis_get_option( 'layout_sbc', 'gpex-settings' ) ) : ?>
						<option <?php ddw_gpex_styles_layout_dropdown( '#ffe4c4' ); ?> value="sidebars-below-content"<?php selected( $this->get_field_value( 'home_layout' ), 'sidebars-below-content' ); ?>><?php _e( 'Sidebars below Content', 'genesis-prose-extras' ); ?></option>
					<?php endif; ?>

					<?php if ( genesis_get_option( 'layout_c_salt', 'gpex-settings' ) ) : ?>
						<option <?php ddw_gpex_styles_layout_dropdown( '#ffe4c4' ); ?> value="content-sidebaralt"<?php selected( $this->get_field_value( 'home_layout' ), 'content-sidebaralt' ); ?>><?php _e( 'Content/Sidebar-Alt', 'genesis-prose-extras' ); ?></option>
					<?php endif; ?>

					<?php if ( genesis_get_option( 'layout_salt_c', 'gpex-settings' ) ) : ?>
						<option <?php ddw_gpex_styles_layout_dropdown( '#ffe4c4' ); ?> value="sidebaralt-content"<?php selected( $this->get_field_value( 'home_layout' ), 'sidebaralt-content' ); ?>><?php _e( 'Sidebar-Alt/Content', 'genesis-prose-extras' ); ?></option>
					<?php endif; ?>

				</select>
				<small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<a href="' . admin_url( 'admin.php?page=genesis#genesis-theme-settings-layout' ) . '">' . __( 'Genesis Default', 'genesis-prose-extras' ) . '</a>' ); ?>)</small>
			</p>

		<?php } else { ?>

			<p>
				<span class="description"><?php echo '<strong>&rarr;</strong> ' . sprintf( __( 'To choose your preferred layout option, just use the %s setting via %s plugin settings.', 'genesis-prose-extras' ), '&raquo;' . __( 'Homepage', 'genesis-prose-extras' ) . '&laquo;', '<a href="' . admin_url( 'admin.php?page=gle-layout-extras' ) . '"><em>' . __( 'Genesis Layout Extras', 'genesis-prose-extras' ) . '</em></a>' ); ?></span>
			</p>

		<?php }  // end-if "Genesis Layout Extras" plugin check ?>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_home_template_metabox' */
	    do_action( 'gpex_home_template_metabox' );

	}  // end of method gpex_home_template_metabox


	/**
	 * Navigation Menus Metabox.
	 *
	 * @since 1.0.0
	 */
	function gpex_navigation_menus_metabox() {

		/** Begin form code <img src="%3$s" alt="%1$s" /><br /> <input type="radio" name="%4$s" id="%5$s" value="%5$s" %6$s /> */
		?>

		<h4><?php _e( 'Navigation Menu Positions.', 'genesis-prose-extras' ); ?></h4>

		<fieldset>
			<legend><?php echo sprintf( __( 'Choose the positions of the %s and %s menus:', 'genesis-prose-extras' ), '<em>' . __( 'Primary Navigation', 'genesis-prose-extras' ) . '</em>', '<em>' . __( 'Secondary Navigation', 'genesis-prose-extras' ) . '</em>' ); ?></legend>

			<div class="gpex-menu-positions">
				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_default' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_default' ); ?>" value="default" <?php checked( $this->get_field_value( 'menu_positions' ), 'default' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_default.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Prose default', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Prose default', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_reverse_default' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_reverse_default' ); ?>" value="reverse_default" <?php checked( $this->get_field_value( 'menu_positions' ), 'reverse_default' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_default-reversed.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Reverse default', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Reverse default', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_double_below' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_double_below' ); ?>" value="double_below" <?php checked( $this->get_field_value( 'menu_positions' ), 'double_below' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_double-below.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Double, below Header', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Double, below Header', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_double_above' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_double_above' ); ?>" value="double_above" <?php checked( $this->get_field_value( 'menu_positions' ), 'double_above' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_double-above.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Double, above Header', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Double, above Header', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_primary_topbar' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_primary_topbar' ); ?>" value="primary_topbar" <?php checked( $this->get_field_value( 'menu_positions' ), 'primary_topbar' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_primary-topbar.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Primary as Top Bar (outsite wrap)', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Primary as Top Bar (outsite wrap)', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'menu_positions_secondary_topbar' ); ?>"><input type="radio" name="<?php echo $this->get_field_name( 'menu_positions' ); ?>" id="<?php echo $this->get_field_id( 'menu_positions_secondary_topbar' ); ?>" value="secondary_topbar" <?php checked( $this->get_field_value( 'menu_positions' ), 'secondary_topbar' ); ?> /><img src="<?php echo plugins_url( 'images/gpex_secondary-topbar.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Secondary as Top Bar (outsite wrap)', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-radio"><?php _e( 'Secondary as Top Bar (outsite wrap)', 'genesis-prose-extras' ); ?></div>
				</label>
			</div>
			<br class="clear" />
		</fieldset>

		<hr class="div" />

		<h4><?php _e( 'Menu Descriptions.', 'genesis-prose-extras' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'menu_descriptions' ); ?>" id="<?php echo $this->get_field_id( 'menu_descriptions' ); ?>" value="1"<?php checked( $this->get_field_value( 'menu_descriptions' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'menu_descriptions' ); ?>"><?php echo sprintf( __( 'Enable menu descriptions for the %s and %s?', 'genesis-prose-extras' ), '<em>' . __( 'Primary Navigation', 'genesis-prose-extras' ) . '</em>', '<em>' . __( 'Secondary Navigation', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'disabled', 'genesis-prose-extras' ) ); ?>)</small></label>
			</p>

			<p>
				<span class="description"><?php echo sprintf( __( 'Note: Even if this option is enabled you still need to enable the input field on %s admin, via %s tab on top right.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'nav-menus.php' ) . '"><em>' . __( 'Nav Menu', 'genesis-prose-extras' ) . '</em></a>', '<em>&raquo;' . __( 'Screen Options', 'genesis-prose-extras' ) . '&laquo;</em>' ) . ' ' . sprintf( __( 'Also, additional CSS styling for the descriptions should be added via %s.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'admin.php?page=prose-custom#prose-custom-css' ) . '"><em>' . __( 'Prose Custom CSS', 'genesis-prose-extras' ) . '</em></a>' ); ?></span>
			</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_navigation_menus_metabox' */
	    do_action( 'gpex_navigation_menus_metabox' );

	}  // end of method gpex_navigation_menus_metabox


	/**
	 * Layouts Metabox.
	 *
	 * @since 1.0.0
	 */
	function gpex_layouts_metabox() {

		/** Begin form code */
		?>

		<h4><?php _e( 'Additional Layout Options.', 'genesis-prose-extras' ); ?></h4>

		<fieldset>
			<legend><?php echo __( 'Enable any additional layout option:', 'genesis-prose-extras' ); ?></legend>

			<div class="gpex-add-layouts">
				<label class="box" for="<?php echo $this->get_field_id( 'layout_sbc' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'layout_sbc' ); ?>" id="<?php echo $this->get_field_id( 'layout_sbc' ); ?>" value="1" <?php checked( $this->get_field_value( 'layout_sbc' ) ); ?> /><img src="<?php echo plugins_url( 'images/gpex_sbc.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Sidebars below Content', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-checkbox"><?php _e( 'Sidebars below Content', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'layout_c_salt' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'layout_c_salt' ); ?>" id="<?php echo $this->get_field_id( 'layout_c_salt' ); ?>" value="1" <?php checked( $this->get_field_value( 'layout_c_salt' ) ); ?> /><img src="<?php echo plugins_url( 'images/gpex_c-salt.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Content/Sidebar-Alt', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-checkbox"><?php _e( 'Content/Sidebar-Alt', 'genesis-prose-extras' ); ?></div>
				</label>

				<label class="box" for="<?php echo $this->get_field_id( 'layout_salt_c' ); ?>"><input type="checkbox" name="<?php echo $this->get_field_name( 'layout_salt_c' ); ?>" id="<?php echo $this->get_field_id( 'layout_salt_c' ); ?>" value="1" <?php checked( $this->get_field_value( 'layout_salt_c' ) ); ?> /><img src="<?php echo plugins_url( 'images/gpex_salt-c.gif', dirname( __FILE__ ) ); ?>" title="<?php esc_html_e( 'Sidebar-Alt/Content', 'genesis-prose-extras' ); ?>" /><br /><div class="gpex-checkbox"><?php _e( 'Sidebar-Alt/Content', 'genesis-prose-extras' ); ?></div>
				</label>
			</div>
			<br class="clear" />
		</fieldset>

		<p class="description">
			<?php _e( 'Note: Only the two Genesis default sidebars are used!', 'genesis-prose-extras' ); ?>
		</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_layouts_metabox' */
	    do_action( 'gpex_layouts_metabox' );

	}  // end of method gpex_layouts_metabox


	/**
	 * Main Content Area Metabox.
	 *
	 * @since 1.0.0
	 */
	function gpex_main_content_area_metabox() {

		/** Begin form code */
		?>

		<h4><?php echo sprintf( __( '%s for Single Posts and Pages.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'widgets.php' ) . '" title="' . __( 'Go to the Widgets settings page', 'genesis-prose-extras' ) . '">' . __( 'Widget areas', 'genesis-prose-extras' ) . '</a>' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'after_post_widget_area' ); ?>" id="<?php echo $this->get_field_id( 'after_post_widget_area' ); ?>" value="1"<?php checked( $this->get_field_value( 'after_post_widget_area' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'after_post_widget_area' ); ?>">
					<?php echo sprintf( __( 'Enable %s widget area for Single Posts?', 'genesis-prose-extras' ), '<em>' . __( 'After Post', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>
			<p class="description">
				&uarr; <?php _e( 'Note: This widget area comes by default with Prose and is enabled.', 'genesis-prose-extras' ); ?>
			</p>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'after_page_widget_area' ); ?>" id="<?php echo $this->get_field_id( 'after_page_widget_area' ); ?>" value="1"<?php checked( $this->get_field_value( 'after_page_widget_area' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'after_page_widget_area' ); ?>">
					<?php echo sprintf( __( 'Enable %s widget area for Single Pages?', 'genesis-prose-extras' ), '<em>' . __( 'Prose After Page', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?>)</small>
				</label>
			</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_main_content_area_metabox' */
	    do_action( 'gpex_main_content_area_metabox' );

	}  // end of method gpex_main_content_area_metabox


	/**
	 * Prose Translations Metabox.
	 *
	 * @since 1.0.0
	 */
	function gpex_prose_translations_metabox() {

		/** Begin form code */
		?>

		<h4><?php _e( 'Set type of Prose translations to be loaded for frontend &amp; backend.', 'genesis-prose-extras' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'formal_translations' ); ?>" id="<?php echo $this->get_field_id( 'formal_translations' ); ?>" value="1"<?php checked( $this->get_field_value( 'formal_translations' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'formal_translations' ); ?>"><?php echo sprintf( __( 'Load %s for Prose Child Theme?', 'genesis-prose-extras' ), '<em>' . __( 'formal translations', 'genesis-prose-extras' ) . '</em>' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'enabled', 'genesis-prose-extras' ) ); ?>)</small></label>
			</p>

			<p>
				<span class="description"><?php echo sprintf( __( 'Note: If %s are unchecked, then informal version will be loaded automatically.', 'genesis-prose-extras' ), '<em>' . __( 'formal translations', 'genesis-prose-extras' ) . '</em>' ); ?></span>
			</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_prose_translations_metabox' */
	    do_action( 'gpex_prose_translations_metabox' );

	}  // end of method gpex_prose_translations_metabox


	/**
	 * Multisite Site Functions Metabox.
	 *
	 * @since  1.0.0
	 *
	 * @uses   prose_get_stylesheet_location()
	 *
	 * @global integer $blog_id 
	 */
	function gpex_multisite_files_metabox() {

		/** Get the Site/ Blog ID */
		global $blog_id;

		/** Set the functions file path */
		$gpex_multisite_path = prose_get_stylesheet_location( 'path' ) . 'functions-site-' . $blog_id . '.php';

		/** Begin form code */
		?>

		<h4><?php _e( 'Load and use extra Site specific functions files.', 'genesis-prose-extras' ); ?></h4>

			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'multisite_files' ); ?>" id="<?php echo $this->get_field_id( 'multisite_files' ); ?>" value="1"<?php checked( $this->get_field_value( 'multisite_files' ) ); ?> />
				<label for="<?php echo $this->get_field_id( 'multisite_files' ); ?>"><?php _e( 'Load Site specific functions files?', 'genesis-prose-extras' ); ?> <small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), __( 'disabled', 'genesis-prose-extras' ) ); ?>)</small></label>
			</p>

			<p>
				<span class="description"><?php echo sprintf( __( 'Note: If enabled a special named functions file has to exist in the following path for this sub site (ID: %s) that is using the Prose child theme.', 'genesis-prose-extras' ), '<code>' . $blog_id . '</code>' ); ?>
					<br />&rarr; <?php echo sprintf( __( 'File name: %s', 'genesis-prose-extras' ), '<code>functions-site-<strong>' . $blog_id . '</strong>.php</code>' ); ?>
					<br />&rarr; <?php echo sprintf( __( 'File path: %s', 'genesis-prose-extras' ), '<code>' . $gpex_multisite_path . '</code>' ); ?></span>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'multisite_hook' ); ?>"><?php _e( 'Set an appropriate Action Hook:', 'genesis-prose-extras' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'multisite_hook' ); ?>" id="<?php echo $this->get_field_id( 'multisite_hook' ); ?>">

					<option value="after_setup_theme"<?php selected( $this->get_field_value( 'multisite_hook' ), 'after_setup_theme' ); ?>><?php echo sprintf( __( '%s &#x2014; theme specific (default)', 'genesis-prose-extras' ), '<code>after_setup_theme</code>' ); ?></option>

					<option value="init"<?php selected( $this->get_field_value( 'multisite_hook' ), 'init' ); ?>><?php echo sprintf( __( '%s &#x2014; plugin specific', 'genesis-prose-extras' ), '<code>init</code>' ); ?></option>

					<option value="genesis_before"<?php selected( $this->get_field_value( 'multisite_hook' ), 'genesis_before' ); ?>><?php echo sprintf( __( '%s &#x2014; Genesis specific', 'genesis-prose-extras' ), '<code>genesis_before</code>' ); ?></option>

				</select>
				<br /><small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<code>after_setup_theme</code>' ); ?>)</small>
			</p>

			<p>
				<label for="<?php echo $this->get_field_id( 'multisite_priority' ); ?>"><?php _e( 'Set the loading priority for the Action Hook:', 'genesis-prose-extras' ); ?></label>
				<select name="<?php echo $this->get_field_name( 'multisite_priority' ); ?>" id="<?php echo $this->get_field_id( 'multisite_priority' ); ?>">

					<option value="10"<?php selected( $this->get_field_value( 'multisite_priority' ), 10 ); ?>><?php echo sprintf( __( '%s &#x2014; WordPress default', 'genesis-prose-extras' ), '<code>10</code>' ); ?></option>

					<option value="5"<?php selected( $this->get_field_value( 'multisite_priority' ), 5 ); ?>><?php echo sprintf( __( '%s &#x2014; load earlier', 'genesis-prose-extras' ), '<code>5</code>' ); ?></option>

					<option value="15"<?php selected( $this->get_field_value( 'multisite_priority' ), 15 ); ?>><?php echo sprintf( __( '%s &#x2014; load later', 'genesis-prose-extras' ), '<code>15</code>' ); ?></option>

					<option value="20"<?php selected( $this->get_field_value( 'multisite_priority' ), 20 ); ?>><?php echo sprintf( __( '%s &#x2014; load later', 'genesis-prose-extras' ), '<code>20</code>' ); ?></option>

					<option value="25"<?php selected( $this->get_field_value( 'multisite_priority' ), 25 ); ?>><?php echo sprintf( __( '%s &#x2014; load later', 'genesis-prose-extras' ), '<code>25</code>' ); ?></option>

					<option value="100"<?php selected( $this->get_field_value( 'multisite_priority' ), 100 ); ?>><?php echo sprintf( __( '%s &#x2014; load later', 'genesis-prose-extras' ), '<code>100</code>' ); ?></option>

				</select>
				<br /><small>(<?php echo sprintf( __( 'Default: %s', 'genesis-prose-extras' ), '<code>10</code>' ); ?>)</small>
			</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_multisite_files_metabox' */
	    do_action( 'gpex_multisite_files_metabox' );

	}  // end of method gpex_multisite_files_metabox


	/**
	 * Export/ Import Metabox.
	 *
	 * @since 1.0.0
	 *
	 * @uses  admin_url()
	 * @uses  wp_get_current_user()
	 * @uses  current_user_can()
	 * @uses  current_theme_supports()
	 * @uses  get_the_author_meta()
	 */
	function gpex_export_import_metabox() {

		/** Helper links/ strings */
		if ( class_exists( 'Widget_Data' ) ) {

			$gpex_wsie_link = '<a href="' . admin_url( 'tools.php?page=widget-settings-export' ) . '">';
			$gpex_wsie_status = __( 'currently active', 'genesis-prose-extras' );
			$gpex_wsie_action = ' &rarr; <em><a href="' . admin_url( 'tools.php?page=widget-settings-export' ) . '">' . __( 'Export', 'genesis-prose-extras' ) . '</a> / <a href="' . admin_url( 'tools.php?page=widget-settings-import' ) . '">' . __( 'Import', 'genesis-prose-extras' ) . '</a></em>';

		} else {

			$gpex_wsie_link = '<a href="http://wordpress.org/plugins/widget-settings-importexport/" target="_new">';
			$gpex_wsie_status = __( 'not active/ installed', 'genesis-prose-extras' );
			$gpex_wsie_action = '';

		}  // end-if WSIE plugin check

		/** Get current user - needed for Genesis menu check */
		$gpex_user = wp_get_current_user();

		/** Begin form code */
		?>

		<?php 	if ( current_user_can( 'edit_theme_options' )
					&& current_theme_supports( 'genesis-import-export-menu' )
					&& get_the_author_meta( 'genesis_import_export_menu', $gpex_user->ID )
				) {
		?>

			<h4><?php _e( 'Export and import plugin settings.', 'genesis-prose-extras' ); ?></h4>

				<p>
					&rarr; <?php echo sprintf( __( 'Hooked in and done via regular %s.', 'genesis-prose-extras' ), '<a href="' . admin_url( 'admin.php?page=genesis-import-export' ) . '">' . __( 'Genesis Export/ Import', 'genesis-prose-extras' ) . '</a>' ); ?>
				</p>

				<p>
					<span class="description"><?php _e( 'Tip: You can do it for this plugin alone or combine plugin settings with Prose and/ or Genesis settings to transfer settings from one Genesis/ Prose site to another.', 'genesis-prose-extras' ); ?></span>
				</p>

			<hr class="div" />

		<?php }  // end-if cap & user check ?>

		<h4><?php _e( 'Widget settings export and import.', 'genesis-prose-extras' ); ?></h4>

			<p>
				&rarr; <?php echo sprintf( __( 'Recommended plugin for that task: %s', 'genesis-prose-extras' ), $gpex_wsie_link . __( 'Widget Settings Importer/ Exporter', 'genesis-prose-extras' ) . '</a>' ) . $gpex_wsie_action; ?>
				<br /> &nbsp;&nbsp;&nbsp;&nbsp;<small>(<?php echo sprintf( __( 'Plugin status: %s', 'genesis-prose-extras' ), '<em>' . $gpex_wsie_status . '</em>' ); ?>)</small>
			</p>

			<p>
				<span class="description"><?php _e( 'Note: This is a third-party WordPress plugin. Use at your own risk!', 'genesis-prose-extras' ); ?></span>
			</p>

		<?php
		/** ^End form code */

		/** Action Hook 'gpex_export_import_metabox' */
	    do_action( 'gpex_export_import_metabox' );

	}  // end of method gpex_export_import_metabox


	/**
	 * Set up the Help Tab system.
	 *
	 * @since 1.0.0
	 *
	 * @uses  callback functions located in theme file
	 *        '/includes/gpex-admin-settings-help.php' with the actual help tab content
	 * @uses  get_current_screen()
	 * @uses  WP_Screen::add_help_tab()
	 * @uses  WP_Screen::set_help_sidebar()
	 * @uses  ddw_gpex_help_sidebar_content()
	 * @uses  ddw_gpex_help_sidebar_content_extra()
	 */
	 function help() {

		/** Get current screen */
	 	$screen = get_current_screen();

		/** Display help tabs only for WordPress 3.3 or higher */
		if ( ! class_exists( 'WP_Screen' ) || ! $screen ) {
			return;
		}

		/** Add starting/general help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-plugin-start-help', 
			'title'    => __( 'Genesis Prose Extras', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_start', 'ddw_gpex_plugin_start_help' ),
		) );

		/** Add Widget Areas help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-widget-areas-help', 
			'title'    => __( 'Widget Areas', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_widget_areas', 'ddw_gpex_widget_areas_help' ),
		) );

		/** Add Custom CSS help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-custom-css-help', 
			'title'    => __( 'Custom CSS', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_custom_css', 'ddw_gpex_custom_css_help' ),
		) );

		/** Add Layout Extras help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-layout-extras-help', 
			'title'    => __( 'Layouts', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_layout_extras', 'ddw_gpex_layout_extras_help' ),
		) );

		/** Add Multisite Extras help tab */
		if ( is_multisite() && is_super_admin() ) {

			$screen->add_help_tab( array(
				'id'       => 'gpex-multisite-help', 
				'title'    => __( 'Multisite Extras', 'genesis-prose-extras' ),
				'callback' => apply_filters( 'gpex_filter_help_content_multisite', 'ddw_gpex_multisite_help' ),
			) );

		}  // end-if multisite check

		/** Add Shortcodes help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-shortcodes-help', 
			'title'    => __( 'Shortcodes', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_shortcodes', 'ddw_gpex_shortcodes_help' ),
		) );
		
		/** Add Translations help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-plugin-translations-help', 
			'title'    => __( 'Translations', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_translations', 'ddw_gpex_plugin_translations_help' ),
		) );

		/** Add Recommended Plugins help tab */
		$screen->add_help_tab( array(
			'id'       => 'gpex-recommended-plugins-help', 
			'title'    => __( 'Recommended Plugins', 'genesis-prose-extras' ),
			'callback' => apply_filters( 'gpex_filter_help_content_recommended_plugins', 'ddw_gpex_recommended_plugins_help' ),
		) );

		/** Add help sidebar */
		$screen->set_help_sidebar( ddw_gpex_help_sidebar_content_extra() . ddw_gpex_space_helper() . ddw_gpex_help_sidebar_content() );

	}  // end of method help

}  // end of class


add_action( 'genesis_admin_menu', 'ddw_gpex_settings_menu' );
/**
 * Instantiate the class to create the menu.
 *
 * @since  1.0.0
 *
 * @param  $gpex_plugin_settings
 *
 * @global mixed $gpex_plugin_settings
 */
function ddw_gpex_settings_menu() {

	global $gpex_plugin_settings;

	$gpex_plugin_settings = new DDW_GPEX_Plugin_Settings;

}  // end of function ddw_gpex_settings_menu


/**
 * Helper function for echoing the some inline styles for the layout dropdown
 *    in this plugin settings.
 *
 * @since 1.0.0
 *
 * @param string 	$gpex_bg
 */
function ddw_gpex_styles_layout_dropdown( $gpex_bg = '' ) {

	echo sprintf(
		'style="padding: 3px 10px 3px 3px; background-color: %s;"',
		esc_attr( $gpex_bg )
	);

}  // end of function ddw_gpex_styles_layout_dropdown